@@ -197,12 +197,14 @@ class RelayTransport(object):
         self._streams = {}
         self._last_stream_id = 0
         self._read_event = asyncio.Event()
-        asyncio.ensure_future(self.process_packet_task())
 
     @property
     def streams(self):
         return list(self._streams.values())
 
+    def start_transport(self):
+        asyncio.ensure_future(self.process_packet_task())
+
     def closed(self):
         return self._tunnel.closed()
 
@@ -550,3 +552,16 @@ def create_random_string(length=32, exclude=None):
             continue
         result += c
     return result
+
+def win32_daemon():
+    cmdline = []
+    for it in sys.argv:
+        if it not in ("-d", "--daemon"):
+            cmdline.append(it)
+
+    DETACHED_PROCESS = 8
+    subprocess.Popen(
+        cmdline,
+        creationflags=DETACHED_PROCESS,
+        close_fds=True
+    )
